@@ -376,6 +376,7 @@ def setVariables():
                         if newtest == True:
                             testtoadd = line
                             if encodetests == "true":
+                                testtoadd = testtoadd.encode('unicode_escape').decode()
                                 testtoadd = testtoadd.replace("\\", "\\\\")
                                 testtoadd = strip_non_ascii(testtoadd)
                                 #testtoadd = testtoadd.replace("\\u00F6", "")
@@ -660,6 +661,7 @@ def get_and_run_tests(type):
             count = count + 1
             testName = element["name"]
             if encodetests == "true":
+                testName = testName.encode('unicode_escape').decode()
                 testName = testName.replace("\\", "\\\\")
                 testName = strip_non_ascii(testName)
                 #testtoadd = testtoadd.replace("\\u00F6", "")
@@ -1811,6 +1813,7 @@ def runtestswithappsurify(*args):
                     if newtest == True:
                         testtoadd = line
                         if encodetests == "true":
+                            testtoadd = testtoadd.encode('unicode_escape').decode()
                             testtoadd = testtoadd.replace("\\", "\\\\")
                             testtoadd = strip_non_ascii(testtoadd)
                             #testtoadd = testtoadd.replace("\\u00F6", "")
@@ -1849,7 +1852,7 @@ def runtestswithappsurify(*args):
             #print (f'##vso[task.setvariable variable={azurefilter}{azure_variable}{variable_num}]{testsrun}') 
         else:
             if azurefilter != "":
-                if azurefilter.endswith('&') is False and azurefilter.endswith('&') is False:
+                if azurefilter.endswith('&') is False and azurefilter.endswith('|') is False:
                     azurefilter = azurefilter + "&"
             print (f'##vso[task.setvariable variable={azure_variable}]{azurefilter}({testsrun})')
             while len(testsrun) > max_length:
